# Update log

## 0.5.0 (April 2020)

- Fixed missing graphlet certificates for fast graphlet identification
- Added more helpful progress bars for the Weisfeiler lehman decomposition
- Added progress bar to pvdbow trainer and removed some performance decreasing instantiations that were not not being used.


## 0.1.1 (March 2020)

- Initial version
- Contains all items described in the paper
